"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var aws_cognito_common_1 = require("./aws-cognito.common");
var AWSCognitoIdentityInteractiveAuthenticationDelegateImpl_1 = require("./ios/AWSCognitoIdentityInteractiveAuthenticationDelegateImpl");
var AWSCognitoIdentityPasswordAuthenticationImpl_1 = require("./ios/AWSCognitoIdentityPasswordAuthenticationImpl");
exports.invokeOnRunLoop = (function () {
    var runLoop = CFRunLoopGetMain();
    return function (func) {
        CFRunLoopPerformBlock(runLoop, kCFRunLoopDefaultMode, func);
        CFRunLoopWakeUp(runLoop);
    };
}());
var AwsCognito = (function (_super) {
    __extends(AwsCognito, _super);
    function AwsCognito() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AwsCognito.createUserPool = function (region, cliendId, secretId, poolId, delegate) {
        var regionValue = AWSRegionType[region];
        this.awsServiceConfiguration = AWSServiceConfiguration.alloc().initWithRegionCredentialsProvider(regionValue, null);
        this.awsCognitoIdentityUserPoolConfiguration = AWSCognitoIdentityUserPoolConfiguration.alloc().initWithClientIdClientSecretPoolId(cliendId, secretId, poolId);
        AWSCognitoIdentityUserPool.registerCognitoIdentityUserPoolWithConfigurationUserPoolConfigurationForKey(this.awsServiceConfiguration, this.awsCognitoIdentityUserPoolConfiguration, "UserPool");
        this.awsCognitoIdentityUserPool = AWSCognitoIdentityUserPool.CognitoIdentityUserPoolForKey("UserPool");
        this.awsCognitoIdentityPasswordAuthenticationImpl = new AWSCognitoIdentityPasswordAuthenticationImpl_1.AWSCognitoIdentityPasswordAuthenticationImpl();
        var awsCognitoIdentityInteractiveAuthenticationDelegateImpl;
        awsCognitoIdentityInteractiveAuthenticationDelegateImpl = new AWSCognitoIdentityInteractiveAuthenticationDelegateImpl_1.AWSCognitoIdentityInteractiveAuthenticationDelegateImpl();
        awsCognitoIdentityInteractiveAuthenticationDelegateImpl.setCognitoIdentityInteractiveAuthenticationDelegate(delegate);
        awsCognitoIdentityInteractiveAuthenticationDelegateImpl.setAWSCognitoIdentityPasswordAuthenticationImpl(this.awsCognitoIdentityPasswordAuthenticationImpl);
        this.awsCognitoIdentityUserPool.delegate = awsCognitoIdentityInteractiveAuthenticationDelegateImpl;
    };
    AwsCognito.registerUser = function (userName, password, attrubutes, delegate) {
        var userPool;
        userPool = AWSCognitoIdentityUserPool.CognitoIdentityUserPoolForKey("UserPool");
        var awsCognitoIdentityUserAttributeType;
        var awsAttributes;
        awsAttributes = new NSMutableArray({ capacity: attrubutes.length });
        for (var _i = 0, attrubutes_1 = attrubutes; _i < attrubutes_1.length; _i++) {
            var temp = attrubutes_1[_i];
            awsCognitoIdentityUserAttributeType = AWSCognitoIdentityUserAttributeType.alloc().initWithNameValue(temp.key, temp.value);
            awsAttributes.addObject(awsCognitoIdentityUserAttributeType);
        }
        var awsTask;
        awsTask = userPool.signUpPasswordUserAttributesValidationData(userName, password, awsAttributes, null);
        awsTask.continueWithBlock(function (task) {
            exports.invokeOnRunLoop(function () {
                if (task.error) {
                    delegate.onError(task.error.userInfo.valueForKey("message"));
                }
                else {
                    delegate.onSuccess(null);
                }
            });
        });
    };
    AwsCognito.confirmSignUp = function (userName, verifyCode, delegate) {
        var userPool;
        userPool = AWSCognitoIdentityUserPool.CognitoIdentityUserPoolForKey("UserPool");
        var awsUser = userPool.getUser(userName);
        var awsTask = awsUser.confirmSignUp(verifyCode);
        awsTask.continueWithBlock(function (task) {
            exports.invokeOnRunLoop(function () {
                if (task.error) {
                    delegate.onError(task.error.userInfo.valueForKey("message"));
                }
                else {
                    delegate.onSuccess(null);
                }
            });
        });
    };
    AwsCognito.getUserDetail = function (delegate) {
        var userPool;
        userPool = AWSCognitoIdentityUserPool.CognitoIdentityUserPoolForKey("UserPool");
        var awsUser = userPool.currentUser();
        var awsTask = awsUser.getDetails();
        awsTask.continueWithBlock(function (task) {
            exports.invokeOnRunLoop(function () {
                if (task.error) {
                    delegate.onError(task.error.userInfo.description);
                }
                else {
                    var map = new Map();
                    for (var i = 0; i < task.result.userAttributes.count; i++) {
                        map.set(task.result.userAttributes[i].name, task.result.userAttributes[i].value);
                    }
                    map.set("userName", task.result.username);
                    delegate.onSuccess(map);
                }
            });
        });
    };
    AwsCognito.login = function (userName, password, delegate) {
        this.awsCognitoIdentityPasswordAuthenticationImpl.setCognitoCommonDelegate(delegate);
        var awsCognitoIdentityPasswordAuthenticationDetails;
        awsCognitoIdentityPasswordAuthenticationDetails = AWSCognitoIdentityPasswordAuthenticationDetails.alloc().initWithUsernamePassword(userName, password);
        this.awsCognitoIdentityPasswordAuthenticationImpl.getPasswordAuthenticationCompletionSource().setResult(awsCognitoIdentityPasswordAuthenticationDetails);
    };
    AwsCognito.signOut = function () {
        var userPool;
        userPool = AWSCognitoIdentityUserPool.CognitoIdentityUserPoolForKey("UserPool");
        var awsUser = userPool.currentUser();
        awsUser.signOut();
    };
    return AwsCognito;
}(aws_cognito_common_1.Common));
exports.AwsCognito = AwsCognito;
//# sourceMappingURL=aws-cognito.ios.js.map